#!/usr/bin/python
# -*- coding: utf-8 -*-
### BEGIN LICENSE
# Copyright (C) 2009 <David Planella> <david.planella@ubuntu.com>
#This program is free software: you can redistribute it and/or modify it
#under the terms of the GNU General Public License version 3, as published
#by the Free Software Foundation.
#
#This program is distributed in the hope that it will be useful, but
#WITHOUT ANY WARRANTY; without even the implied warranties of
#MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
#PURPOSE.  See the GNU General Public License for more details.
#
#You should have received a copy of the GNU General Public License along
#with this program.  If not, see <http://www.gnu.org/licenses/>.
### END LICENSE

from gviz_api import gviz_api
import csv
import sys
from LocaleInfo import LocaleInfo
from datetime import datetime
import simplejson as json

JSON_FILE = '/home/dpm/public_html/data/langpacks_by_inst.json'

page_template = """
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
    "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">
  <head>
  <meta http-equiv="Content-Type" content="text/html;charset=utf-8" />
  <title>Language packs</title>
    <script src="http://www.google.com/jsapi" type="text/javascript"></script>
    <script type="text/javascript">

      var json_data = %(langpacks_json)s

      google.load("visualization", "1", {packages:["table"]});
      google.load("visualization", "1", {packages:["columnchart"]});
      google.setOnLoadCallback(draw);

      function draw() {
          drawTable();
          drawChart();
      }

      function drawTable() {
          var langpack_table_data = new google.visualization.DataTable(json_data, 0.6);
          var langpack_table = new google.visualization.Table(
            document.getElementById('table_div_langpack'));

          langpack_table.draw(langpack_table_data, {
              showRowNumber: true,
              page: 'enable',
              pageSize: 20});
      }

      function drawChart() {
          var langpack_table_data = new google.visualization.DataTable(json_data, 0.6);
          var langpack_chart_view = new google.visualization.DataView(langpack_table_data, 0.6);

          langpack_chart_view.setRows(range(1, 21));
          var langpack_chart = new google.visualization.ColumnChart(
              document.getElementById('column_chart_div_langpack'));

          langpack_chart.draw(langpack_chart_view, {
              width: 650,
              height: 400,
              title: 'Language packs by installation',
              legend: 'none',
          });
      }

      function range(range_min, range_max) {
          var range_len = range_max - range_min;
          var rangeArr = new Array (range_len);
          var i;
          var range_inc = range_min;

          for (i = 0; i < range_len; i++)
          {
            rangeArr[i] = range_inc++;
          }

          return rangeArr;
      }

    </script>
    <style type="text/css">
        #report-meta {
          text-align: right;
          font-size: small;
          color: #999;
          float: right;
        }

       #report-meta p {
         margin: 0;
       }

    </style>
  </head>
  <body>
    <div id="report-meta">
      <p>Generated on %(gen_date)s</p>
    </div>

    <h1>Top 20 language packs</h1>
    <div id="column_chart_div_langpack" align="center"></div>

    <h1>Language pack installations</h1>
    <div id="table_div_langpack" align="center"></div>

    <form action="data/langpacks_by_inst.csv" method=GET>
      <input type=submit value="Download as CSV">
    </form>

  </body>
</html>
"""

def main():
    # Creating the gviz data description
    description = {"langpack": ("string", "Language pack"),
                    "installs": ("number", "Installations")}

    # Read the data from the JSON file
    f = open(JSON_FILE, 'r')
    data = json.load(f)

    # Load the data it into gviz_api.DataTable
    data_table = gviz_api.DataTable(description)
    data_table.LoadData(data)

    # Create a JSon string
    langpacks_json = data_table.ToJSon(columns_order=("langpack", "installs"),
                                    order_by=("installs", "desc"))

    # Log the date of creation for the report
    gen_date = datetime.utcnow()

    # Put the JSon string into the template
    print page_template % vars()

if __name__ == "__main__":
    main()
