#!/usr/bin/python
# -*- coding: utf-8 -*-
### BEGIN LICENSE
# Copyright (C) 2009 <David Planella> <david.planella@ubuntu.com>
#This program is free software: you can redistribute it and/or modify it
#under the terms of the GNU General Public License version 3, as published
#by the Free Software Foundation.
#
#This program is distributed in the hope that it will be useful, but
#WITHOUT ANY WARRANTY; without even the implied warranties of
#MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
#PURPOSE.  See the GNU General Public License for more details.
#
#You should have received a copy of the GNU General Public License along
#with this program.  If not, see <http://www.gnu.org/licenses/>.
### END LICENSE

import datetime
import urllib2
import urllib
import time
import os
import gzip
import csv
import re
from LocaleInfo import LocaleInfo
import simplejson as json

PUBLIC_DIR='/home/dpm/public_html'
DATA_DIR = data_file = os.path.join(PUBLIC_DIR, 'data')
URL = "http://popcon.ubuntu.com/by_inst.gz"
REGEXP = re.compile("^language-pack-[a-z]{2,3}(-han[st])?-base")
data_file = os.path.join(DATA_DIR, os.path.basename(URL))
CSV_FILE = os.path.join(DATA_DIR, 'langpacks_by_inst.csv')
JSON_FILE = os.path.join(DATA_DIR, 'langpacks_by_inst.json')

def get_http_timestamp(url):
    try:
        sock = urllib2.urlopen(url)
    except:
        return None

    timestamp_lm = None
    if sock.info()["Last-Modified"]:
        lm_string = sock.info()["Last-Modified"]
        sock.close()
        if lm_string:
            timestamp_lm = time.mktime(time.strptime(lm_string, "%a, %d %b %Y %H:%M:%S GMT"))
            datetime_lm = datetime.datetime.fromtimestamp(timestamp_lm)
            return datetime_lm
    return None

def get_file_timestamp(filename):
    try:
        mtime = os.path.getmtime(filename)
    except:
        return None

    return datetime.datetime.utcfromtimestamp(mtime)

def get_langpack_code(langpackname):
    langpack_bits = langpackname.split('-')

    if len(langpack_bits) == 5:
        langpack_code = langpack_bits[2] + '-' + langpack_bits[3]
    else:
        langpack_code = langpack_bits[2]

    return langpack_code

def get_language_name(langcode, li):
    try:
        lang_name = li.translate(langcode, True)
        lname = lang_name.split(';')[0]
    except:
        lname = langcode

    return lname

def main ():
    http_timestamp = get_http_timestamp(URL)
    if http_timestamp != get_file_timestamp(data_file):
        urllib.urlretrieve(URL, data_file)

        # Extract and put the language pack data in a CSV file
        data_csv = csv.reader(gzip.open(data_file), delimiter = ' ', skipinitialspace = True)

        writer = csv.writer(open(CSV_FILE, "wb"))
        writer.writerow(['# Code', 'Installations', 'Language', 'Timestamp'])

        li = LocaleInfo.LocaleInfo()

        data_json = []
        try:
            for row in data_csv:
                try:
                    if REGEXP.search(row[1]):
                        lang_code = get_langpack_code(row[1])
                        installs = row[2]
                        lang_name = get_language_name(lang_code, li)
                        writer.writerow([lang_code, installs, lang_name, http_timestamp])
                        data_json.append({'installs': int(installs), 'langpack': lang_name})
                except:
                    pass
        except csv.Error, e:
            pass
            #print 'file %s, line %d: %s' % (data_file, data_csv.line_num, e)

        f = open(JSON_FILE, mode='w')
        json.dump(data_json, f)

if __name__ == "__main__":
  main()
